@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Config.pm,v 1.81.2.77 2006/01/15 19:52:10 jkf Exp $
+#   $Id: Config.pm 3673 2006-07-25 19:18:34Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ no  strict 'subs'; # Allow bare words for parameter %'s
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.81.2.77 $, 10;
+$VERSION = substr q$Revision: 3673 $, 10;
 
 #1 exception to general rule of forming replies to Config::Value()
 #is %Config::ScannerCmds
@@ -61,8 +61,8 @@ my($LOCK_UN) = 8;
 # This is global within this package to save passing them all over the place
 my(%File, %LineNos, %ItoE, %EtoI);
 my(%StaticScalars, %ScannerCmds, %SpamLists);
-my(%KeywordCategory, %FilenameRules, %FiletypeRules);
-my(%LanguageStrings);
+my(%KeywordCategory, %KeywordType, %FilenameRules, %FiletypeRules);
+my(%LanguageStrings, %YesNoItoE, %YesNoEtoI, %HardCodedDefaults);
 my(%RuleScalars, %Defaults, $DefaultAddressRegexp, $DefaultVirusRegexp);
 my(%CustomFunctions, %CustomFunctionsParams);
 my(%PercentVars); # For putting substituted variables in all settings
@@ -538,7 +538,7 @@ sub IsSimpleValue {
 #
 sub DoPercentVars {
   my($string) = @_;
-  $string =~ s/\%([^%]+)\%/$PercentVars{lc($1)}/g;
+  $string =~ s/\%([^%\s]+)\%/$PercentVars{lc($1)}/g;
   $string =~ s/\\n/\n/g;
   $string;
 }
@@ -563,7 +563,7 @@ sub initialise {
     # Skip all dot files and rpmnew files
     next if $filename =~ /^\./ || $filename =~ /\.(rpmnew|dpkg-dist|dpkg-new|dpkg-old)$/i;
     unless ($filename =~ /\.p[lm]$/i) {
-      MailScanner::Log::InfoLog("Skipping Custom Function file %s as its name does not end in .pm or .pl", $filename);
+      MailScanner::Log::NoticeLog("Skipping Custom Function file %s as its name does not end in .pm or .pl", $filename);
       next;
     }
     $fullfile = "$dir/$filename";
@@ -580,6 +580,14 @@ sub initialise {
 }
 
 
+#
+# Set one of the %percentvars%.
+#
+sub SetPercent {
+  my($percent, $value) = @_;
+  $PercentVars{$percent} = $value;
+}
+
 #
 # Hack quickly through the config file looking for a keyword.
 # Cannot use MailScanner::Log here at all, as it hasn't started yet.
@@ -614,7 +622,7 @@ sub QuickPeek {
     $value =~ s/\$\{?(\w+)\}?/$ENV{$1}/g;
     $value =~ s/\\n/\n/g;
     if ($key =~ /^\%([^%]+)\%$/) {
-      $PercentVars{lc($1)} = $value;
+      $PercentVars{lc($1)} = $value unless exists $PercentVars{lc($1)};
       #next; -- Store the percentvars in the key{value} hash as well.
     }
 
@@ -804,10 +812,17 @@ sub Read {
       MailScanner::Log::WarnLog("Could not use Custom Function code %s, " .
         "it could not be \"eval\"ed. Make sure the module is correct with " .
         "perl -wc", $fn);
+      $StaticScalars{$key} = $Defaults{$key}; # Over-ride if function broken
     }
     use strict 'refs';
   }
 
+  # Read the list of second-level country domain codes that exist
+  %MailScanner::Config::SecondLevelDomainExists = ();
+  ReadCountryDomainList(MailScanner::Config::Value('secondlevellist'))
+    unless MailScanner::Config::IsSimpleValue('strictphishing') &&
+           MailScanner::Config::Value('strictphishing');
+
   # Debug output
   #PrintDefinitions(%ScannerCmds);
   #PrintDefinitions(%SpamLists);
@@ -889,6 +904,39 @@ sub EndCustomFunctions {
   }
 }
 
+# Read the list of second-level domains. We don't check top-level domains
+# as you cannot hide much in there.
+sub ReadCountryDomainList {
+  my ($filename) = @_;
+
+  %MailScanner::Config::SecondLevelDomainExists = ();
+
+  my $fh = new FileHandle;
+  unless ($fh->open("< $filename")) {
+    MailScanner::Log::WarnLog("Could not read list of country code second-level domain names from %s, \"Use Stricter Phishing Net = no\" will not work properly", $filename);
+    return;
+  }
+
+  while(<$fh>) {
+    chomp;
+    s/^#.*$//;   # Remove comments
+    s/^\s*//g;   # Remove leading white space
+    s/\s*$//g;   # Remove trailing white space
+    s/\s+.*$//g; # Leave only the 1st word
+    next if /^$/;
+
+    # Only allow 2 dots at most
+    if (/\..*\..*\./) {
+      # There were at least 3 dots
+      MailScanner::Log::WarnLog("Domain name \"%s\" in %s  is deeper than third-level, ignoring it", $_, $filename);
+      next;
+    }
+    $MailScanner::Config::SecondLevelDomainExists{"$_"} = 1;
+  }
+
+  $fh->close;
+}
+
 
 # Return a ref to a list of all the filename-rules for a message
 # This is done completely separately from the Value() function
@@ -1598,7 +1646,8 @@ sub ReadConfFile {
     $value =~ s/\$\{?(\w+)\}?/$ENV{$1}/g;
     $value =~ s/\\n/\n/g;
     if ($origkey =~ /^\%([^%]+)\%$/) {
-      $PercentVars{lc($1)} = $value;
+      # Always use the first definition of the %variable%
+      $PercentVars{lc($1)} = $value unless exists $PercentVars{lc($1)};
       next;
     }
 
@@ -1857,7 +1906,7 @@ sub RuleToRegexp {
 
   # Handle non-alphabetic regexps as IP number tests.
   # These must not contain any letters.
-  if ($rule =~ s#^/([^a-z]*)/$#$1#) {
+  if ($rule ne '/^$/' && $rule =~ s#^/([^a-z]+)/$#$1#) {
     # Test their rule
     eval { $compiledre = qr/$rule/i; };
     if ($@) {
@@ -2291,10 +2340,18 @@ sub InternalDataValue {
       $internal .= $word;
     } elsif ($rulesettype =~ /number/i) {
       # Number rules can only contain digits and dots and _ and -
-      return undef unless $word =~ /^[\d._-]+$/;
+      #print STDERR "Word is \"$word\"\n";
+      return undef unless $word =~ /^([\d._-]+)([kmgKMG]?)/;
+      $word = $1;
+      my $multiplier = lc $2;
+      #print STDERR "Multiplier = $multiplier, Word = $word\n";
       $internal .= ' ' if $internal ne "";
       $word =~ s/_//g;
+      $word = $word * 1000       if $multiplier eq 'k';
+      $word = $word * 1000000    if $multiplier eq 'm';
+      $word = $word * 1000000000 if $multiplier eq 'g';
       $internal .= $word;
+      #print STDERR "Word = \"$word\"\n";
     } elsif ($rulesettype =~ /command/i) {
       # Command rules must contain executable as first
       # element, then anything
@@ -2379,6 +2436,15 @@ sub ProcessYesNo {
 
   ($keyword, $default, %values) = split(" ", lc($line));
   $KeywordCategory{$keyword} = $category;
+  $KeywordType{$keyword} = 'yesno';
+  $HardCodedDefaults{$keyword} = $default;
+  # Save the %values for when needed to do internal to external conversion
+  $YesNoEtoI{$keyword} = \%values;
+  $YesNoItoE{$keyword} = ();
+  my($key,$value);
+  while (($key,$value) = each %values) {
+    $YesNoItoE{$keyword}{$value} = $key;
+  }
   #$keyword = EtoI($keyword);
   #print STDERR "Config: YesNo keyword \"$keyword\" default \"$default\" " .
   #             "values are \"". %values . "\"\n";
@@ -2454,6 +2520,8 @@ sub ProcessFile {
   ($keyword, $default) = split(" ", $line);
   $keyword = lc($keyword);
   $KeywordCategory{$keyword} = $category;
+  $KeywordType{$keyword} = 'file';
+  $HardCodedDefaults{$keyword} = $default;
   #$keyword = EtoI($keyword);
   #print STDERR "File keyword \"$keyword\" default \"$default\" value \"" .
   #             $File{$keyword} . "\"\n";
@@ -2528,6 +2596,8 @@ sub ProcessCommand {
   ($keyword, $default) = split(" ", $line);
   $keyword = lc($keyword);
   $KeywordCategory{$keyword} = $category;
+  $KeywordType{$keyword} = 'command';
+  $HardCodedDefaults{$keyword} = $default;
   #$keyword = EtoI($keyword);
   #print STDERR "File keyword \"$keyword\" default \"$default\" value \"" .
   #             $File{$keyword} . "\"\n";
@@ -2604,6 +2674,8 @@ sub ProcessDir {
   ($keyword, $default) = split(" ", $line);
   $keyword = lc($keyword);
   $KeywordCategory{$keyword} = $category;
+  $KeywordType{$keyword} = 'dir';
+  $HardCodedDefaults{$keyword} = $default;
   #$keyword = EtoI($keyword);
   #print STDERR "Dir keyword \"$keyword\" default \"$default\" value \"" .
   #             $File{$keyword} . "\n" if $keyword =~ /^in.*dir$/i;
@@ -2627,7 +2699,7 @@ sub ReadNumberValue {
 
   my($first, $isrules);
   $first = $File{$keyword};
-  $isrules = 1 if $first !~ /^[\d._-]*$/; # Rules aren't all digits or ._-
+  $isrules = 1 if $first !~ /^[\d._-]+[kmgKMG]?/; # Rules aren't all digits or ._- followed by optional multiplier
   $isrules = 1 if $LDAP && $first =~ /customi[sz]e|\.RuleSet$/; # LDAP ruleset
 
   # It might be a function name
@@ -2677,6 +2749,8 @@ sub ProcessNumber {
   ($keyword, $default) = split(" ", $line);
   $keyword = lc($keyword);
   $KeywordCategory{$keyword} = $category;
+  $KeywordType{$keyword} = 'number';
+  $HardCodedDefaults{$keyword} = $default;
 
   #print STDERR "Number keyword \"$keyword\" default \"$default\" value \"" .
   #             $File{$keyword} . "\n";
@@ -2750,6 +2824,8 @@ sub ProcessOther {
   ($keyword, $default) = split(" ", $line, 2); # Allow spaces in it
   $keyword = lc($keyword);
   $KeywordCategory{$keyword} = $category;
+  $KeywordType{$keyword} = 'other';
+  $HardCodedDefaults{$keyword} = $default;
   #$keyword = EtoI($keyword);
   #print STDERR "Other keyword \"$keyword\" default \"$default\" value \"" .
   #             $File{$keyword} . "\"\n";
@@ -2763,6 +2839,68 @@ sub ProcessOther {
 
 }
 
+# Go through the configuration we have loaded and try to find all the
+# options whose settings do not match the default.
+# Use &Value to find the current setting, %RuleScalars exists where there
+# is a ruleset for the value, %Defaults contains the default setting.
+# Don't know what happens when there is a %Default which is a pointer to
+# a ruleset, we'll have to find out.
+# Print out a list of all the changed settings, what their default was and
+# what their new value is. If it's a ruleset, just print out "rules".
+sub PrintNonDefaults {
+  my($key, $default, $actual, $external, %Output, $fixed, $fixed2);
+
+  print "\nTable of Changed Values:\n\n";
+  print PrintFixedWidth("Option Name", 35) . PrintFixedWidth("Default", 15) .
+        "Current Value\n";
+  print "=" x 79 . "\n";
+
+  while (($key,$default) = each %HardCodedDefaults) {
+    # This is a cheap Value($key) that won't evaluate Custom Functions
+    $actual = $Defaults{$key};
+    $actual = $StaticScalars{$key} if exists $StaticScalars{$key};
+
+    $external = ItoE($key);
+    # Special case for this one as it is a list of directory names
+    if ($key eq 'inqueuedir') {
+      my @dirs = @{Value('inqueuedir')};
+      $actual = join(',',@dirs);
+    }
+    # Translate the internal numbers into user-readable keywords
+    if ($KeywordType{$key} eq 'yesno') {
+      $default = 0 unless $default;
+      $actual  = 0 unless $actual;
+      $default = $YesNoItoE{$key}{$default};
+      $actual  = $YesNoItoE{$key}{$actual};
+    }
+    $fixed = PrintFixedWidth($external, 35);
+    $fixed2 = PrintFixedWidth($default, 15);
+    $actual =~ s/\n/\\n/g;
+    if ($CustomFunctions{$key}) {
+      # It's a Custom Function
+      $Output{$external} = "$fixed$fixed2" . "FUNCTION:" . $CustomFunctions{$key};
+    } elsif ($RuleScalars{$key}) {
+      # It's a ruleset
+      $Output{$external} = "$fixed$fixed2" . "RULESET:Default=$actual";
+    } else {
+      # It's a scalar
+      $Output{$external} = "$fixed$fixed2$actual"
+        if ($actual ne $default) && !($default eq '0' && $actual eq '');
+    }
+  }
+  foreach $external (sort keys %Output) {
+    print $Output{$external} . "\n";
+  }
+}
+    
+sub PrintFixedWidth {
+  my($text,$width) = @_;
+  my $length = length $text;
+  $text .= ' ';
+  $width--;
+  $text .= ' ' x ($width-$length) if $width > $length;
+  return $text;
+}
 
 # Has the LDAP configuration data changed in the last couple of minutes?
 # Only actually do the LDAP query every 2 minutes, just cache it in
