@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ConfigDefs.pl,v 1.37.2.107 2006/02/23 21:04:48 jkf Exp $
+#   $Id: ConfigDefs.pl 3684 2006-08-03 21:49:18Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -78,6 +78,7 @@ criticalqueuesize		= maxnormalqueuesize
 dangerscan			= dangerouscontentscanning
 deletedcontentmessage		= deletedbadcontentmessagereport
 deletedfilenamemessage		= deletedbadfilenamemessagereport
+deletedsizemessage		= deletedsizemessagereport
 deletedvirusmessage		= deletedvirusmessagereport
 deliverdisinfected		= deliverdisinfectedfiles
 deliversilent			= stilldeliversilentviruses
@@ -157,11 +158,13 @@ sacache				= spamassassincachedatabasefile
 saviwatchfiles                  = monitorsforsophosupdates
 scanmail			= scanmessages
 scoreformat			= spamscorenumberformat
+secondlevellist                 = countrysubdomainslist
 sendercontentreport		= senderbadcontentreport
 senderfilenamereport		= senderbadfilenamereport
 senderrblspamreport		= senderspamlistreport
 sendersaspamreport		= senderspamassassinreport
 sendersamcpreport		= sendermcpreport
+sendersizereport		= sendersizereport
 senderbothspamreport		= senderspamreport
 showscanner			= includescannernameinreports
 signalreadyscanned		= signmessagesalreadyprocessed
@@ -172,6 +175,8 @@ sophoslib			= sophoslibdir
 spamblacklist			= isdefinitelyspam
 spamdetail			= detailedspamreport
 mcpprependsubject		= mcpmodifysubject
+sizeprependsubject		= sizemodifysubject
+sizesubjecttext			= sizesubjecttext
 spamprependsubject		= spammodifysubject
 spamscorenotstars		= spamscorenumberinsteadofstars
 spamstars			= spamscore
@@ -180,8 +185,10 @@ spamstarsheader			= spamscoreheader
 spamwhitelist			= isdefinitelynotspam
 storedcontentmessage		= storedbadcontentmessagereport
 storedfilenamemessage		= storedbadfilenamemessagereport
+storedsizemessage		= storedsizemessagereport
 storedvirusmessage		= storedvirusmessagereport
 storeentireasdfqf		= quarantinewholemessagesasqueuefiles
+strictphishing                  = usestricterphishingnet
 stripdangeroustags		= convertdangeroushtmltotext
 mcpblacklist			= isdefinitelymcp
 mcpblacklistedishigh		= definitemcpishighscoring
@@ -199,6 +206,8 @@ warnsenders			= notifysenders
 warnvirussenders		= notifysendersofviruses
 warnnamesenders			= notifysendersofblockedfilenamesorfiletypes
 warnothersenders		= notifysendersofotherblockedcontent
+webbugurl			= webbugreplacement
+webbugwhitelist			= ignoredwebbugfilenames
 whitelistmaxrecips		= ignorespamwhitelistifrecipientsexceed
 workuser			= incomingworkuser
 workgroup			= incomingworkgroup
@@ -221,12 +230,12 @@ debugspamassassin	0	no	0	yes	1
 deliverinbackground	1	no	0	yes	1
 lognonspam		0	no	0	yes	1
 logsilentviruses	0	no	0	yes	1
-logspam			1	no	0	yes	1
+logspam			0	no	0	yes	1
 logspeed		0	no	0	yes	1
 logmcp			0	no	0	yes	1
 expandtnef		1	no	0	yes	1
 runinforeground		0	no	0	yes	1
-showscanner		0	no	0	yes	1
+showscanner		1	no	0	yes	1
 spamassassinautowhitelist 1	no	0	yes	1
 spliteximspool		0	no	0	yes	1
 storeentireasdfqf	0	no	0	yes	1
@@ -242,6 +251,7 @@ lockfiledir		/tmp
 [Simple,File]
 PhishingWhitelist	/etc/MailScanner/phishing.safe.sites.conf
 pidfile			/var/run/MailScanner.pid
+SecondLevelList         /etc/MailScanner/country.domains.conf
 #spamassassinprefsfile	/etc/MailScanner/spam.assassin.prefs.conf
 SpamListDefinitions	/etc/MailScanner/spam.lists.conf
 mcpspamassassinprefsfile /etc/MailScanner/mcp/mcp.spam.assassin.prefs.conf
@@ -250,29 +260,30 @@ VirusScannerDefinitions	/etc/MailScanner/virus.scanners.conf
 # Check these to ensure they are just numbers
 [Simple,Number]
 BayesRebuild			0
-Children			1
-clamavmaxreclevel               5
+Children			5
+clamavmaxreclevel               8
 clamavmaxfiles                  1000
 clamavmaxfilesize               10000000
 clamavmaxratio                  250
-CriticalQueueSize		5000
-FileTimeout			30
-GSTimeout			40
+CriticalQueueSize		800
+FileTimeout			20
+GSTimeout			20
 GSTimeoutLen			20
+GunzipTimeout			50
 MaxUnscannedBytes		100000000
-MaxUnscannedMessages		100
+MaxUnscannedMessages		30
 MaxDirtyBytes			50000000
-MaxDirtyMessages		100
+MaxDirtyMessages		30
 MaxGSSize			20000
 MaxGSTimeouts			10
 MaxSpamAssassinTimeouts		10
-MaxSpamAssassinSize		50000
-QueueScanInterval		5
+MaxSpamAssassinSize		30000
+QueueScanInterval		6
 RBLTimeoutLen			10
 RestartEvery			14400
-SATimeoutLen			20
-SpamListTimeout			5
-SpamAssassinTimeout		10
+SATimeoutLen			30
+SpamListTimeout			10
+SpamAssassinTimeout		75
 VirusScannerTimeout		300
 MCPMaxSpamAssassinTimeouts	20
 MCPMaxSpamAssassinSize		100000
@@ -280,16 +291,20 @@ MCPSpamAssassinTimeout		10
 TNEFTimeout			120
 UnrarTimeout			50
 WhitelistMaxRecips		20
+# For Qmail users
+qmailhashdirectorynumber	23
+qmailintdhashnumber		1
 
 # These are all the other strings I haven't categorised.
 # inqueuedir is here as it can be a glob (if it contains a * or a ?) or a
 # filename containing a list of directories.
 [Simple,Other]
-cachetiming		1800,1800,10800,172800,1200
+cachetiming		1800,300,10800,172800,600
 ClamWatchFiles		/usr/local/share/clamav/*.cvd
 CustomFunctionsDir	/usr/lib/MailScanner/MailScanner/CustomFunctions
 FileCommand		/usr/bin/file
 FirstCheck		mcp
+GunzipCommand		/bin/gunzip
 inqueuedir		/var/spool/mqueue.in
 LDAPbase
 LDAPserver
@@ -313,6 +328,7 @@ sophoslib
 SpamAssassinUserStateDir
 SpamAssassinSiteRulesDir
 SpamAssassinLocalRulesDir	
+SpamAssassinLocalStateDir	
 SpamAssassinDefaultRulesDir	
 SpamAssassinInstallPrefix	
 SpamStarsCharacter	s
@@ -322,7 +338,7 @@ MCPSpamAssassinDefaultRulesDir	/etc/MailScanner/mcp
 MCPSpamAssassinInstallPrefix	/etc/MailScanner/mcp
 TNEFExpander		/usr/bin/tnef --maxsize=100000000
 UnrarCommand		/usr/bin/unrar
-VirusScanners		none  # Space-separated list
+VirusScanners		auto  # Space-separated list
 WorkUser
 WorkGroup
 WorkPerms		0600
@@ -340,8 +356,8 @@ bouncemcpasattachment	0	no	0	yes	1
 bouncespamasattachment	0	no	0	yes	1
 CheckSAIfOnSpamList	1	no	0	yes	1
 ContentPrependSubject	1	no	0	yes	1
-DeliverDisinfected	1	no	0	yes	1
-DeliverSilent		1	no	0	yes	1
+DeliverDisinfected	0	no	0	yes	1
+DeliverSilent		0	no	0	yes	1
 deliverunparsabletnef	0	no	0	yes	1
 deliverymethod		batch	batch	batch	queue	queue
 DisarmPrependSubject	1	no	0	yes	1
@@ -354,10 +370,10 @@ HighMCPPrependSubject	1	no	0	yes	1
 HighSpamPrependSubject	1	no	0	yes	1
 IncludeSpamHeader	0	no	0	yes	1
 IncludeMCPHeader	0	no	0	yes	1
-KeepSpamArchiveClean	1	no	0	yes	1
+KeepSpamArchiveClean	0	no	0	yes	1
 LastAfterBatch		0	no	0	yes	1
 LastLookup		0	no	0	yes	1
-ListSAScores		0	no	0	yes	1
+ListSAScores		1	no	0	yes	1
 #LoadSpamAssassin	0	no	0	yes	1
 LogHTMLTags		0	no	0	yes	1
 LogPermittedFilenames	0	no	0	yes	1
@@ -365,12 +381,13 @@ LogPermittedFiletypes	0	no	0	yes	1
 LookForUU		0	no	0	yes	1
 MultipleHeaders		append	append	append	replace	replace	add	add
 NamePrependSubject	1	no	0	yes	1
-NoticeFullHeaders	0	no	0	yes	1
+NoticeFullHeaders	1	no	0	yes	1
 scannedmodifysubject	0	no	0	start	start	end	end
 SendNotices		1	no	0	yes	1
 SignAlreadyScanned	0	no	0	yes	1
 SignCleanMessages	1	no	0	yes	1
 SignUnscannedMessages	1	no	0	yes	1
+SizePrependSubject	1	no	0	yes	1
 SpamBlacklist		0	no	0	yes	1
 SpamDetail		1	no	0	yes	1
 SpamChecks		1	no	0	yes	1
@@ -388,7 +405,7 @@ MCPWhitelist		0	no	0	yes	1
 UseSACache		1	no	0	yes	1
 VirusPrependSubject	1	no	0	yes	1
 warningisattachment	1	no	0	yes	1
-WarnSenders		0	no	0	yes	1
+WarnSenders		1	no	0	yes	1
 WarnVirusSenders	0	no	0	yes	1
 WarnNameSenders		1	no	0	yes	1
 WarnOtherSenders	1	no	0	yes	1
@@ -396,6 +413,7 @@ WarnOtherSenders	1	no	0	yes	1
 [First,File]
 DeletedContentMessage	/etc/MailScanner/reports/en/deleted.content.message.txt
 DeletedFilenameMessage	/etc/MailScanner/reports/en/deleted.filename.message.txt
+DeletedSizeMessage	/etc/MailScanner/reports/en/deleted.size.message.txt
 DeletedVirusMessage	/etc/MailScanner/reports/en/deleted.virus.message.txt
 DisinfectedReportText	/etc/MailScanner/reports/en/disinfected.report.txt
 inlinehtmlsig		/etc/MailScanner/reports/en/inline.sig.html
@@ -413,10 +431,12 @@ senderfilenamereport	/etc/MailScanner/reports/en/sender.filename.report.txt
 SenderRBLSpamReport	/etc/MailScanner/reports/en/sender.spam.rbl.report.txt
 SenderSASpamReport	/etc/MailScanner/reports/en/sender.spam.sa.report.txt
 SenderSAMCPReport	/etc/MailScanner/reports/en/sender.mcp.report.txt
+SenderSizeReport	/etc/MailScanner/reports/en/sender.size.report.txt
 SenderBothSpamReport	/etc/MailScanner/reports/en/sender.spam.report.txt
 sendervirusreport 	/etc/MailScanner/reports/en/sender.virus.report.txt
 StoredContentMessage	/etc/MailScanner/reports/en/stored.content.message.txt
 StoredFilenameMessage	/etc/MailScanner/reports/en/stored.filename.message.txt
+StoredSizeMessage	/etc/MailScanner/reports/en/stored.size.message.txt
 StoredVirusMessage	/etc/MailScanner/reports/en/stored.virus.message.txt
 
 [First,Command]
@@ -428,8 +448,8 @@ PublicKeyArchiveDir		#/var/spool/MailScanner/keys
 quarantinedir			/var/spool/MailScanner/quarantine
 
 [First,Number]
-HighRBLs			5
-HighSpamAssassinScore		15
+HighRBLs			3
+HighSpamAssassinScore		10
 MaxAttachmentSize		-1
 MaxMessageSize			0
 MaxParts			200
@@ -441,26 +461,26 @@ MCPReqSpamAssassinScore		1
 MinAttachmentSize		-1
 MinStars			0
 NormalRBLs			1
-ReqSpamAssassinScore		5
+ReqSpamAssassinScore		6
 
 [First,Other]
-AttachmentCharset		us-ascii
+AttachmentCharset		ISO-8859-1
 AttachmentWarningFilename	VirusWarning.txt
 cleanheader			Found to be clean
-ContentSubjectText		{DANGEROUS?}
+ContentSubjectText		{Dangerous Content?}
 dirtyheader			Found to be infected
 DisarmSubjectText		{Disarmed}
 DisinfectedHeader		Disinfected
 EnvFromHeader			X-MailScanner-Envelope-From:
 EnvToHeader			X-MailScanner-Envelope-To:
-HighMCPSubjectText		{Restricted?}
-HighSpamSubjectText		{SPAM?}
+HighMCPSubjectText		{MCP?}
+HighSpamSubjectText		{Spam?}
 Hostname			the MailScanner
 InfoHeader			
-InfoValue			See www.mailscanner.info for information
+InfoValue			Please contact the ISP for more information
 LocalPostmaster			postmaster
 MailHeader			X-MailScanner:
-NameSubjectText			{VIRUS?}
+NameSubjectText			{Filename?}
 NoticesFrom			MailScanner
 NoticeSignature			-- \nMailScanner\nEmail Virus Scanner\nwww.mailscanner.info
 PhishingSubjectTag		{Fraud?}
@@ -469,45 +489,48 @@ ScoreFormat			%d
 Sendmail2			/usr/sbin/sendmail
 SpamHeader			X-MailScanner-SpamCheck:
 SpamList
-MCPSubjectText			{Restricted?}
-SpamSubjectText			{SPAM?}
+MCPSubjectText			{MCP?}
+SpamSubjectText			{Spam?}
 SpamStarsHeader			X-MailScanner-SpamScore:
 MCPHeader			X-MailScanner-MCPCheck:
 UnscannedHeader			Not scanned: please contact your Internet E-Mail Service Provider for details
-VirusSubjectText		{VIRUS?}
-HamActions		deliver
-SpamActions		deliver
-HighScoreSpamActions	deliver
+VirusSubjectText		{Virus?}
+WebBugURL			http://www.mailscanner.info/images/1x1spacer.gif
+HamActions		deliver header "X-Spam-Status: No"
+SpamActions		deliver header "X-Spam-Status: Yes"
+HighScoreSpamActions	deliver header "X-Spam-Status: Yes"
 NonMCPActions		deliver
 MCPActions		deliver
 HighScoreMCPActions	deliver
+SizeSubjectText		{Size}
 
 [All,YesNo]
-AddEnvFrom		0	no	0	yes	1
+AddEnvFrom		1	no	0	yes	1
 AddEnvTo		0	no	0	yes	1
-AllowIFrameTags		0	no	0	yes	1	disarm	convert
-AllowFormTags		0	no	0	yes	1	disarm	convert
-AllowObjectTags		0	no	0	yes	1	disarm	convert
-AllowScriptTags		0	no	0	yes	1	disarm	convert
+AllowIFrameTags		convert	no	0	yes	1	disarm	convert
+AllowFormTags		convert	no	0	yes	1	disarm	convert
+AllowObjectTags		convert	no	0	yes	1	disarm	convert
+AllowScriptTags		convert	no	0	yes	1	disarm	convert
 AllowPassZips		0	no	0	yes	1
-AllowWebBugTags		1	no	0	yes	1	disarm	convert
+AllowWebBugTags		convert	no	0	yes	1	disarm	convert
 BlockEncrypted		0	no	0	yes	1
 BlockUnencrypted	0	no	0	yes	1
 DangerScan		1	no	0	yes	1
 DeliverCleanedMessages	1	no	0	yes	1
-FindPhishing		0	no	0	yes	1
+FindPhishing		1	no	0	yes	1
 markinfectedmessages	1	no	0	yes	1
 PhishingHighlight	1	no	0	yes	1
 HtmlToText		0	no	0	yes	1
 PhishingNumbers		1	no	0	yes	1
 QuarantineInfections	1	no	0	yes	1
 QuarantineModifiedBody	0	no	0	yes	1
-QuarantineSilent	1	no	0	yes	1
+QuarantineSilent	0	no	0	yes	1
 QuarantineWholeMessage	0	no	0	yes	1
 RejectMessage		0	no	0	yes	1
 ReplaceTNEF		2	no	0	add	1	replace	2
 ScanMail		1	no	0	yes	1
-SpamStars		0	no	0	yes	1
+SpamStars		1	no	0	yes	1
+StrictPhishing          1       no      0       yes     1
 TagPhishingSubject	0	no	0 	yes	1
 MCPUseSpamAssassin	1	no	0	yes	1
 UseSpamAssassin		1	no	0	yes	1
@@ -522,12 +545,13 @@ VirusScan		1	no	0	yes	1
 ArchiveMail
 FilenameRules		
 FiletypeRules		
-NoisyViruses			wm97
-NoSenderPrecedence
+NoisyViruses			Joke/ OF97/ WM97/ W97M/ eicar
+NoSenderPrecedence		list bulk
 NoticeRecipient			postmaster
-RemoveHeaders
-SilentViruses			All-Viruses
+RemoveHeaders			X-Mozilla-Status: X-Mozilla-Status2:
+SilentViruses			HTML-IFrame All-Viruses
 SpamDomainList			
+webbugwhitelist
 allowfilenames
 denyfiletypes
 allowfiletypes
