@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Log.pm,v 1.14.2.10 2006/01/14 19:24:15 jkf Exp $
+#   $Id: Log.pm 3665 2006-07-21 09:40:06Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ sub Start {
         # Sys::Syslog::setlogsock('stream');
       # }
     };
-    Sys::Syslog::openlog($name, 'pid, nowait', $facility);
+    eval { Sys::Syslog::openlog($name, 'pid, nowait', $facility); };
   }
   
   if (defined $Banner) {
@@ -107,6 +107,15 @@ sub WarnLog {
   carp $logmessage if $LogType eq 'stderr';
 }
 
+sub NoticeLog {
+  my(@x) = @_;
+  my $logmessage = sprintf shift @x, @x;
+
+  LogText($logmessage, 'notice');
+
+  print STDERR "$logmessage\n" if $LogType eq 'stderr';
+}
+
 sub InfoLog {
   my(@x) = @_;
   my $logmessage = sprintf shift @x, @x;
@@ -140,7 +149,7 @@ sub LogText {
 
   foreach(split /\n/,$logmessage) {
     s/%/%%/g;
-    Sys::Syslog::syslog($level, $_) if $_ ne "";
+    eval { Sys::Syslog::syslog($level, $_) if $_ ne "" };
 
     ## If we got a SIGPIPE then something broke in the logging socket.
     ## So try to open a new one and use that from now on instead.
