@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: MessageBatch.pm,v 1.64.2.49 2006/03/02 22:45:24 jkf Exp $
+#   $Id: MessageBatch.pm 3684 2006-08-03 21:49:18Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ use Time::HiRes qw ( time );
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.64.2.49 $, 10;
+$VERSION = substr q$Revision: 3684 $, 10;
 
 my $maxcleanbytes    = 0;
 my $maxcleanmessages = 0;
@@ -104,16 +104,18 @@ sub EndBatch {
   $totaltime = 1 unless $totaltime > 0.001; # Minimum of 1 m-second
   $speed = ($totalbytes*1.0) / ($totaltime*1.0) if $totaltime > 0;
   $this->{bytespersecond} = $speed;
-  MailScanner::Log::InfoLog("Batch completed at %d bytes per second (%d / %d)",
-                            $speed, $totalbytes, $now-$this->{starttime})
-    if MailScanner::Config::Value('logspeed');
+  $speed = 0 if $speed > 1_000_000 || $speed < 0;
+  if (MailScanner::Config::Value('logspeed')) {
+    MailScanner::Log::InfoLog("Batch completed at %d bytes per second (%d / %d)",
+                              $speed, $totalbytes, $now-$this->{starttime});
 
-  # Work out current size of batch.
-  my $msgs = $this->{messages};
-  my $msgcount = scalar(keys %$msgs);
+    # Work out current size of batch.
+    my $msgs = $this->{messages};
+    my $msgcount = scalar(keys %$msgs);
 
-  MailScanner::Log::InfoLog("Batch (%d messages) processed in %.2f seconds",
-                            $msgcount, $totaltime);
+    MailScanner::Log::InfoLog("Batch (%d message%s) processed in %.2f seconds",
+                              $msgcount, ($msgcount==1?'':'s'), $totaltime);
+  }
 }
 
 # Start the timing for a section of the main code
@@ -154,13 +156,14 @@ sub StopTiming {
   $totaltime = 1 unless $totaltime > 0; # Minimum of 1 second
   # speed = bytes / totaltime
   $speed = ($this->{totalbytes}*1.0) / ($totaltime*1.0) if $totaltime > 0;
+  $speed = 0 if $speed > 1_000_000 || $speed < 0;
   # bytespersecond = speed
   $command = '$this->{' . $varprefix . '_bytespersecond} = $speed;';
   eval $command;
 
   MailScanner::Log::InfoLog("%s completed at %d bytes per second",
                             $usertext, $speed)
-    if MailScanner::Config::Value('logspeed');
+    if MailScanner::Config::Value('logspeed') && $speed > 0;
 }
 
 # This must be called as a class method before new() is used
@@ -260,7 +263,7 @@ sub SpamChecks {
                                ($message->{isspam}?'spam':'notspam'));
     }
   }
-  MailScanner::Log::InfoLog("Spam Checks: Found $counter spam messages")
+  MailScanner::Log::NoticeLog("Spam Checks: Found $counter spam messages")
     if $counter>0;
   #print STDERR "$counter messages were spam\n";
 }
@@ -354,7 +357,7 @@ sub MCPChecks {
     }
     #print STDERR "Spam header = \"" . $message->{spamreport} . "\"\n";
   }
-  MailScanner::Log::InfoLog("MCP Checks: Found $counter MCP messages")
+  MailScanner::Log::NoticeLog("MCP Checks: Found $counter MCP messages")
     if $counter>0;
   #print STDERR "$counter messages were spam\n";
 }
@@ -488,17 +491,17 @@ sub VirusScan {
   # Call them with the scanning settings
   MailScanner::Log::InfoLog("Virus and Content Scanning: Starting");
   my $viruses = MailScanner::SweepViruses::ScanBatch($this, 'scan');
-  MailScanner::Log::InfoLog("Virus Scanning: Found %d viruses", $viruses+0)
+  MailScanner::Log::NoticeLog("Virus Scanning: Found %d viruses", $viruses+0)
     if defined $viruses && $viruses>0;
 
   #MailScanner::Log::InfoLog("Other Checks: Starting");
   my $others  = MailScanner::SweepOther::ScanBatch($this, 'scan');
-  MailScanner::Log::InfoLog("Other Checks: Found %d problems", $others+0)
+  MailScanner::Log::NoticeLog("Other Checks: Found %d problems", $others+0)
     if defined $others && $others>0;
 
   #MailScanner::Log::InfoLog("Content Checks: Starting");
   my $content  = MailScanner::SweepContent::ScanBatch($this, 'scan');
-  MailScanner::Log::InfoLog("Content Checks: Found %d problems", $content+0)
+  MailScanner::Log::NoticeLog("Content Checks: Found %d problems", $content+0)
     if defined $content && $content>0;
 }
 
@@ -690,7 +693,7 @@ sub QuarantineModifiedBody {
             /1/;
 
     $global::MS->{quar}->StoreInfections($message);
-    MailScanner::Log::InfoLog("Quarantining modified message for %s", $id);
+    MailScanner::Log::NoticeLog("Quarantining modified message for %s", $id);
   }
 }
 
@@ -800,7 +803,7 @@ sub DeliverOrDeleteSilent {
 
   if (@messages) {
     MailScanner::Mail::TellAbout(@messages);
-    MailScanner::Log::InfoLog("Silent: Delivered %d messages containing " .
+    MailScanner::Log::NoticeLog("Silent: Delivered %d messages containing " .
                               "silent viruses", scalar(@messages));
   }
 }
@@ -823,7 +826,7 @@ sub DeliverCleaned {
 
   MailScanner::Mail::TellAbout(@messages);
 
-  MailScanner::Log::InfoLog("Cleaned: Delivered %d cleaned messages",
+  MailScanner::Log::NoticeLog("Cleaned: Delivered %d cleaned messages",
                             scalar(@messages)) if @messages;
 }
 
@@ -858,7 +861,7 @@ sub WarnSenders {
                   $warnviruses;
     $reasons++ if $message->{nameinfected}  &&
                   MailScanner::Config::Value('warnnamesenders', $message);
-    $reasons++ if $message->{otherinfected} &&
+    $reasons++ if ($message->{otherinfected} || $message->{sizeinfected}) &&
                   MailScanner::Config::Value('warnothersenders', $message);
     next if $reasons==0;
 
@@ -866,7 +869,7 @@ sub WarnSenders {
     $counter++;
   }
 
-  MailScanner::Log::InfoLog("Sender Warnings: Delivered %d warnings to " .
+  MailScanner::Log::NoticeLog("Sender Warnings: Delivered %d warnings to " .
                             "virus senders", $counter) if $counter;
 }
 
@@ -902,6 +905,7 @@ sub WarnLocalPostmaster {
       $reasons{virusinfected}     = 1 if $message->{virusinfected};
       $reasons{filenameinfected}  = 1 if $message->{nameinfected};
       $reasons{otherinfected}     = 1 if $message->{otherinfected};
+      $reasons{sizeinfected}      = 1 if $message->{sizeinfected};
       $reasons{passwordprotected} = 1 if $message->{passwordprotected};
       foreach $thisreason (sort keys %reasons) {
         $reasons .= " : " if $reasons ne "";
@@ -931,7 +935,7 @@ sub WarnLocalPostmaster {
                                 $!);
   }
 
-  MailScanner::Log::InfoLog("Notices: Warned about %d messages", $counter)
+  MailScanner::Log::NoticeLog("Notices: Warned about %d messages", $counter)
     if $counter;
 }
 
@@ -970,7 +974,7 @@ sub DisinfectAndDeliver {
   # Nothing to do?
   return unless @interesting;
 
-  MailScanner::Log::InfoLog("Disinfection: Attempting to disinfect %d " .
+  MailScanner::Log::NoticeLog("Disinfection: Attempting to disinfect %d " .
                             "messages", scalar(@interesting));
 
   # Save the infection reports, they will be needed to compare
@@ -998,7 +1002,7 @@ sub DisinfectAndDeliver {
   # Now re-scan the batch to find revised virus reports
   my $viruses = MailScanner::SweepViruses::ScanBatch($this, 'rescan');
   #print STDERR "Revised scanning found $viruses viruses\n";
-  MailScanner::Log::InfoLog("Disinfection: Rescan found only %d viruses",
+  MailScanner::Log::NoticeLog("Disinfection: Rescan found only %d viruses",
                             $viruses+0);
 
   # Look through the original list of reports, finding reports that
@@ -1021,7 +1025,7 @@ sub ArchiveToFilesystem {
     $log .= " " . $id if $DidAnything;
   }
 
-  MailScanner::Log::InfoLog("Saved archive copies of%s", $log) if $log;
+  MailScanner::Log::NoticeLog("Saved archive copies of%s", $log) if $log;
 }
 
 
@@ -1097,11 +1101,15 @@ sub LastLookup {
   unless (MailScanner::Config::IsSimpleValue('lastlookup') &&
           !MailScanner::Config::Value('lastlookup')) {
     MailScanner::Log::InfoLog("\"Always Looked Up Last\" took %.2f seconds",
-                              time-$start+0.0);
+                              time-$start+0.0)
+      if MailScanner::Config::Value('logspeed') =~ /1/;
   }
 
   # Lookup one remaining value after end of batch
-  MailScanner::Config::Value('lastafterbatch');
+  # Putting in $this is against the rules as it isn't a message,
+  # but it doesn't actually cause any problems and gives MailWatch
+  # a way of getting hold of the batch statistics.
+  MailScanner::Config::Value('lastafterbatch', $this);
 }
 
 1;
