@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Postfix.pm,v 1.1.2.66 2005/12/07 14:00:49 jkf Exp $
+#   $Id: Postfix.pm 3667 2006-07-23 11:53:50Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.66 $, 10;
+$VERSION = substr q$Revision: 3667 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -285,8 +285,11 @@ sub new {
     my($ip, $TOline);
     my($Line, $Flags);
     my($MsgContSize, $DataOffset, $NumRecips);
-    my($TOFound, $FROMFound, $IPFound, $TIMEFound);
+    # ORIGFound stuff courtesy of Juan Pablo Abuyeres 23/7/2006
+    # Should improve handling of virtual domains.
+    my($ORIGFound, $TOFound, $FROMFound, $IPFound, $TIMEFound);
     my($ErrorFound, $ERecordFound, $rectype, $recdata);
+    my $InSubject = 0; # Are we adding continuation subject lines?
 
     #print STDERR "In ReadQf\n";
     #$message->{store}->print();
@@ -369,6 +372,7 @@ sub new {
         push @{$message->{to}}, lc($recdata);
         push @{$message->{metadata}}, "$rectype$recdata";
         $TOFound = 1;
+        $ORIGFound = 1;
         #print STDERR "Pre R Recip $recdata\n";
       #JKF 20040322 } elsif ($rectype eq 'O') {
       } elsif ($rectype eq 'R') {
@@ -379,7 +383,7 @@ sub new {
         $recdata =~ s/^\<//;
         $recdata =~ s/\<$//;
         $recdata = lc($recdata);
-        push @{$message->{to}}, lc($recdata);
+        push @{$message->{to}}, lc($recdata) unless $ORIGFound;
         push @{$message->{metadata}}, "$rectype$recdata";
         #JKF 20040322 $message->{originalrecips}{"$recdata"} = 1;
         $message->{postfixrecips}{lc("$recdata")} = 1;
@@ -406,14 +410,20 @@ sub new {
       push @{$message->{headers}}, $recdata; # Headers have no leading N
       if ($recdata =~ /^Subject:\s*(\S.*)?$/i) {
         $message->{subject} = $1;
+        $InSubject = 1;
         next;
       }
-      # JKF Testing code -- Must remove before release
-      #if ($recdata =~ /^X-ClientIP:\s*(\S+)$/i) {
-      #  $message->{clientip} = $1;
-      #  $IPFound = 1;
-      #}
-      # JKF Testing code ends -- Must remove before release
+      if ($InSubject) {
+        if ($recdata =~ /^\s/) {
+          # We are in a continuation line, so remove the leading whitespace
+          $recdata =~ s/^\s//;
+          $message->{subject} .= $recdata;
+          next;
+        } else {
+          # Line did not start with continuation character so we're not in Subj
+          $InSubject = 0;
+        }
+      }
       if (!$IPFound && $recdata =~ /^Received: .+\[(\d+\.\d+\.\d+\.\d+)\]/i) {
         $message->{clientip} = $1;
         $IPFound = 1;
@@ -458,6 +468,7 @@ sub new {
         push @{$message->{to}}, lc($recdata);
         push @{$message->{metadata}}, "$rectype$recdata";
         $TOFound = 1;
+        $ORIGFound = 1;
         #print STDERR "Post R Recip $recdata\n";
       #JKF 20040322 } elsif ($rectype eq 'O') {
       } elsif ($rectype eq 'R') {
@@ -467,7 +478,8 @@ sub new {
         $recdata =~ s/^\<//;
         $recdata =~ s/\<$//;
         $recdata = lc($recdata);
-        push @{$message->{to}}, $recdata;
+        #push @{$message->{to}}, $recdata;
+        push @{$message->{to}}, lc($recdata) unless $ORIGFound;
         push @{$message->{metadata}}, "$rectype$recdata";
         #JKF 20040322 $message->{originalrecips}{"$recdata"} = 1;
         $message->{postfixrecips}{"$recdata"} = 1;
@@ -508,7 +520,18 @@ sub new {
     # Over-ride the default default character set handler so it does it
     # much better than the MIME-tools default handling.
     MIME::WordDecoder->default->handler('*' => \&MailScanner::Message::WordDecoderKeep7Bit);
-    $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
+    my $TmpSubject = MIME::WordDecoder::unmime($message->{subject});
+    if ($TmpSubject ne $message->{subject}) {
+      # The unmime function dealt with an encoded subject, as it did
+      # something. Allow up to 10 trailing spaces so that SweepContent
+      # is more kind to us and doesn't go and replace the whole subject,
+      # thinking that it is malicious. Total replacement and hence
+      # destruction of unicode subjects is rather harsh when we are just
+      # talking about a few spaces.
+      $TmpSubject =~ s/ {1,10}$//;
+      $message->{subject} = $TmpSubject;
+    }
+    #old $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
 
     # If we never found the E (end of message file) record, then
     # Postfix is definitely still writing the message.
@@ -1425,7 +1448,7 @@ sub FindHashDirDepth {
     } while $batchempty; # Keep trying until we get something
 
     # Log the number of invalid messages found
-    MailScanner::Log::InfoLog("New Batch: Found invalid queue files: %s",
+    MailScanner::Log::NoticeLog("New Batch: Found invalid queue files: %s",
                               $invalidfiles)
       if $invalidfiles;
     # Log the size of the queue if it is more than 1 batch
