@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: RBLs.pm,v 1.18.2.16 2005/10/03 16:18:42 jkf Exp $
+#   $Id: RBLs.pm 3638 2006-06-17 20:28:07Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use IO;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.18.2.16 $, 10;
+$VERSION = substr q$Revision: 3638 $, 10;
 
 #my %spamlistfailures; # Number of consecutive failures for both lists
 
@@ -274,7 +274,7 @@ sub Checks {
   #MailScanner::Log::WarnLog("8 PID is $pid");
 
   # The return from the pipe is a measure of how spammy it was
-  MailScanner::Log::InfoLog("RBL checks: %s found in %s", $message->{id},
+  MailScanner::Log::NoticeLog("RBL checks: %s found in %s", $message->{id},
                             join(', ', @HitList))
     if @HitList && MailScanner::Config::Value('logspam');
   MailScanner::Log::DebugLog("RBL Checks: returned $PipeReturn");
