@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SA.pm,v 1.35.2.72 2006/02/01 22:19:57 jkf Exp $
+#   $Id: SA.pm 3553 2006-05-09 19:51:10Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ use Compress::Zlib;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.35.2.72 $, 10;
+$VERSION = substr q$Revision: 3553 $, 10;
 
 # Attributes are
 #
@@ -104,6 +104,8 @@ sub initialise {
     $settings{userstate_dir} = $val if $val ne "";
     $val = MailScanner::Config::Value('spamassassinlocalrulesdir');
     $settings{LOCAL_RULES_DIR} = $val if $val ne "";
+    $val = MailScanner::Config::Value('spamassassinlocalstatedir');
+    $settings{LOCAL_STATE_DIR} = $val if $val ne "";
     $val = MailScanner::Config::Value('spamassassindefaultrulesdir');
     $settings{DEF_RULES_DIR} = $val if $val ne "";
     $val = MailScanner::Config::Value('spamassassininstallprefix');
@@ -349,6 +351,7 @@ sub Checks {
   my($dfhandle);
   my($dfilename, $dfile, @WholeMessage, $SAResult, $SAHitList);
   my($HighScoring, $SAScore, $maxsize, $SAReport, $GSHits);
+  my $GotFromCache = undef; # Did the result come from the cache?
   $GSHits = $message->{gshits} || 0.0;
 
   # Bail out and fake a miss if too many consecutive SA checks failed
@@ -492,9 +495,6 @@ sub Checks {
     $testcache = MailScanner::Config::Value("usesacache",$message);
     $testcache = ($testcache =~ /1/)?1:0;
     $md5 = Digest::MD5->new;
-    #foreach(@WholeBody) {
-    #  $md5->add($_);
-    #}
     eval { $md5->add(@WholeBody) };
     if ($@ ne "" || @WholeBody<=1) {
       # The eval failed
@@ -529,6 +529,10 @@ sub Checks {
        uncompress($cachehash->{saheader}),   $cachehash->{sascore},
        uncompress($cachehash->{salongreport}));
 
+      # Log the fact we got it from the cache. Must not add the "cached"
+      # word on the front here or it will be put into the cache itself!
+      $GotFromCache = 1;
+
       #print STDERR "Cache results are $SAResult, $HighScoring, $SAHitList, $SAScore, $SAReport\n";
       # Unlock and close the lockfile
       flock($RebuildLockH, $LOCK_UN) if $MailScanner::SA::DoingBayesRebuilds; # $BayesIsLocked;
@@ -550,6 +554,11 @@ sub Checks {
                           \@WholeMessage, $message);
       }
 
+      # Log the fact we didn't get it from the cache. Must not add the
+      # "not cached" word on the front here or it will be put into the
+      # cache itself!
+      $GotFromCache = 0;
+
       #MailScanner::Log::WarnLog("Done SAForkAndTest");
       #print STDERR "SAResult = $SAResult\nHighScoring = $HighScoring\n" .
       #             "SAHitList = $SAHitList\n";
@@ -557,10 +566,23 @@ sub Checks {
       # Write the record to the cache *****
       CacheResult($md5digest, $SAResult, $HighScoring, compress($SAHitList), $SAScore, compress($SAReport));
 
+
       # Unlock and close the lockfile
       flock($RebuildLockH, $LOCK_UN) if $MailScanner::SA::DoingBayesRebuilds; # $BayesIsLocked;
       $RebuildLockH->close() if $MailScanner::SA::DoingBayesRebuilds;
     }
+
+    # Add the cached / not cached tag to $SAHitList if appropriate
+    if (defined($GotFromCache)) {
+      if ($GotFromCache) {
+        $SAHitList = MailScanner::Config::LanguageValue($message, 'cached')
+                     . ', ' . $SAHitList;
+      } else {
+        $SAHitList = MailScanner::Config::LanguageValue($message, 'notcached')
+                     . ', ' . $SAHitList;
+      }
+    }
+
   } else {
     # No cache here
 
