@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Sendmail.pm,v 1.56.2.38 2006/02/21 19:28:33 jkf Exp $
+#   $Id: Sendmail.pm 3687 2006-08-04 15:13:01Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.56.2.38 $, 10;
+$VERSION = substr q$Revision: 3687 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -89,7 +89,7 @@ sub new {
   # JKF 2006-01-23 Changed default to posix as this probably is now what
   #                most systems (particularly new ones) have.
   $this->{LockType} = "posix";
-  $this->{LockType} = "flock";
+  #$this->{LockType} = "flock";
   # Patch by Kevin Spicer to detect HASFLOCK
   # JKF -- Does not work as old sendmail versions don't say HASFLOCK but do.
   # Automatically detect locking type
@@ -365,7 +365,18 @@ my($sed) = "/bin/sed";
     # Over-ride the default default character set handler so it does it
     # much better than the MIME-tools default handling.
     MIME::WordDecoder->default->handler('*' => \&MailScanner::Message::WordDecoderKeep7Bit);
-    $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
+    my $TmpSubject = MIME::WordDecoder::unmime($message->{subject});
+    if ($TmpSubject ne $message->{subject}) {
+      # The unmime function dealt with an encoded subject, as it did
+      # something. Allow up to 10 trailing spaces so that SweepContent
+      # is more kind to us and doesn't go and replace the whole subject,
+      # thinking that it is malicious. Total replacement and hence
+      # destruction of unicode subjects is rather harsh when we are just
+      # talking about a few spaces.
+      $TmpSubject =~ s/ {1,10}$//;
+      $message->{subject} = $TmpSubject;
+    }
+    #old $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
     #print STDERR "After decode subject is \"" . $message->{subject} . "\"\n";
 
     # Every qf file should at least define the sender, 1 recipient and the
@@ -503,7 +514,13 @@ my($sed) = "/bin/sed";
     for($linenum=0; $linenum<@{$message->{metadata}}; $linenum++) {
       next unless $message->{metadata}[$linenum] =~ /^H(\?[^?]*\?)?$key/i;
       $oldlocation = $linenum;
-      last;
+      # Patch by ian@blenke.com to modify all subject lines instead of just
+      # the first one, as many Mail apps and webmail systems use the last
+      # subject line and not the first one. This will slightly impact the
+      # speed but not greatly.
+      # last;
+      $message->{metadata}[$oldlocation] =~
+        s/^H(\?[^?]*\?)?$key\s*/H$1$key $newvalue$sep/i;
     }
 
     # Didn't find it?
@@ -512,8 +529,9 @@ my($sed) = "/bin/sed";
       return;
     }
 
-    $message->{metadata}[$oldlocation] =~
-      s/^H(\?[^?]*\?)?$key\s*/H$1$key $newvalue$sep/i;
+    # Part of ian@blenke.com patch
+    #$message->{metadata}[$oldlocation] =~
+    #  s/^H(\?[^?]*\?)?$key\s*/H$1$key $newvalue$sep/i;
   }
 
   sub TextStartsHeader {
@@ -672,9 +690,11 @@ my($sed) = "/bin/sed";
 
   sub KickMessage {
     my(@ids) = @_;
-    my($idlist);
+    my $idlist = '';
 
-    $idlist = join(' -qI', @ids);
+    my $outqdir = MailScanner::Config::Value('outqueuedir');
+    $idlist = " -OQueueDirectory=$outqdir " if $outqdir;
+    $idlist .= join(' -qI', @ids);
     $idlist .= ' &' if MailScanner::Config::Value('deliverinbackground');
     #print STDERR "About to do \"Sendmail2 -qI$idlist\"\n";
     system(MailScanner::Config::Value('sendmail2') . ' -qI' . $idlist);
@@ -988,7 +1008,7 @@ my($sed) = "/bin/sed";
     } while $batchempty; # Keep trying until we get something
 
     # Log the number of invalid messages found
-    MailScanner::Log::InfoLog("New Batch: Found invalid queue files: %s",
+    MailScanner::Log::NoticeLog("New Batch: Found invalid queue files: %s",
                               $invalidfiles)
       if $invalidfiles;
     # Log the size of the queue if it is more than 1 batch
@@ -996,14 +1016,14 @@ my($sed) = "/bin/sed";
                               $MsgsInQueue)
       if $MsgsInQueue > ($DirtyMsgs+$CleanMsgs);
 
-    MailScanner::Log::InfoLog("New Batch: Forwarding %d unscanned messages, " .
+    MailScanner::Log::NoticeLog("New Batch: Forwarding %d unscanned messages, " .
                               "%d bytes", $CleanMsgs, $CleanBytes)
       if $CleanMsgs;
     MailScanner::Log::InfoLog("New Batch: Scanning %d messages, %d bytes",
                               $DirtyMsgs, $DirtyBytes)
       if $DirtyMsgs;
 
-    #MailScanner::Log::InfoLog("New Batch: Archived %d $ArchivedMsgs messages",
+    #MailScanner::Log::NoticeLog("New Batch: Archived %d $ArchivedMsgs messages",
     #                          $ArchivedMsgs)
     #  if $ArchivedMsgs;
 
@@ -1088,8 +1108,8 @@ sub CheckQueueIsFlat {
   # Remember the dir was nested if necessary
   $IsNestedQueue{$dir} = ($FoundQf && $FoundDf)?1:0;
   #print STDERR "Set IsNestedQueue for $dir so now " . join(',',%IsNestedQueue) . "\n";
-  MailScanner::Log::InfoLog("Queue directory %s is nested", $dir)
-    if $FoundQf && $FoundDf;
+  #MailScanner::Log::NoticeLog("Queue directory %s is nested", $dir)
+  #  if $FoundQf && $FoundDf;
 
   return 1;
 }
