@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SweepContent.pm,v 1.17.2.29 2006/02/21 19:28:33 jkf Exp $
+#   $Id: SweepContent.pm 3684 2006-08-03 21:49:18Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.17.2.29 $, 10;
+$VERSION = substr q$Revision: 3684 $, 10;
 
 # Attributes are
 #
@@ -129,8 +129,8 @@ sub ScanBatch {
                                 "%d bytes", $message->{id}, $maxmessagesize);
       $message->{otherreports}{""} .=
         MailScanner::Config::LanguageValue($message, 'toobig') . "\n";
-      $message->{othertypes}{""} .= "e";
-      $message->{otherinfected}++;
+      $message->{othertypes}{""} .= "s";
+      $message->{sizeinfected}++;
       $counter++;
     }
 
@@ -309,23 +309,24 @@ sub CheckAttachmentSizes {
     if ($maxsize>=0 && $attachsize > $maxsize) {
       #print STDERR "$safename is too big $attachsize > $maxsize\n";
       #print STDERR "Unsafename is $unsafename\n";
-      MailScanner::Log::InfoLog("Attachment size check: %s > %s (%s) in %s",
+      MailScanner::Log::NoticeLog("Attachment size check: %s > %s (%s) in %s",
                                 $attachsize, $maxsize, $unsafename, $id);
       $message->{otherreports}{$safename} .=
-       MailScanner::Config::LanguageValue($message,'attachmenttoolarge') . "\n";
-      $message->{othertypes}{$safename}   .= "e";
+       MailScanner::Config::LanguageValue($message,'attachmenttoolarge') .
+         ": $attachsize bytes\n";
+      $message->{othertypes}{$safename}   .= "s";
       $counter++;
-      $message->{otherinfected}++;
+      $message->{sizeinfected}++;
     }
     if ($minsize>=0 && $attachsize < $minsize) {
       #print STDERR "Attachment is too small\n";
-      MailScanner::Log::InfoLog("Attachment size check: %s < %s (%s) in %s",
+      MailScanner::Log::NoticeLog("Attachment size check: %s < %s (%s) in %s",
                                 $attachsize, $minsize, $unsafename, $id);
       $message->{otherreports}{$safename} .=
        MailScanner::Config::LanguageValue($message,'attachmenttoosmall') . "\n";
-      $message->{othertypes}{$safename}   .= "e";
+      $message->{othertypes}{$safename}   .= "s";
       $counter++;
-      $message->{otherinfected}++;
+      $message->{sizeinfected}++;
     }
   }
 
@@ -508,7 +509,7 @@ sub SearchHTMLBody {
     }
     if ($iframefound) {
       # Log the <IFrame>
-      MailScanner::Log::InfoLog("HTML-IFrame tag found in message %s from %s",
+      MailScanner::Log::NoticeLog("HTML-IFrame tag found in message %s from %s",
         $id, $message->{from}) if $loggingtags;
       # Mark the message
       if ($allowiframes) {
@@ -531,7 +532,7 @@ sub SearchHTMLBody {
     }
     if ($formfound) {
       ## Log the <Form>
-      MailScanner::Log::InfoLog("HTML-Form tag found in message %s from %s",
+      MailScanner::Log::NoticeLog("HTML-Form tag found in message %s from %s",
         $id, $message->{from}) if $loggingtags;
       # Mark the message
       if ($allowforms) {
@@ -554,7 +555,7 @@ sub SearchHTMLBody {
     }
     if ($scriptfound) {
       ## Log the <script>
-      MailScanner::Log::InfoLog("HTML-Script tag found in message %s from %s",
+      MailScanner::Log::NoticeLog("HTML-Script tag found in message %s from %s",
         $id, $message->{from}) if $loggingtags;
       # Mark the message
       if ($allowscripts) {
@@ -577,7 +578,7 @@ sub SearchHTMLBody {
     }
     if ($webbugfound) {
       ## Log the <img>
-      MailScanner::Log::InfoLog("HTML Img tag found in message %s from %s",
+      MailScanner::Log::NoticeLog("HTML Img tag found in message %s from %s",
         $id, $message->{from}) if $loggingtags;
       #  if MailScanner::Config::Value('logwebbugs', $message);
       # Mark the message
@@ -609,7 +610,7 @@ sub SearchHTMLBody {
       }
     }
     if ($codebasefound) {
-      MailScanner::Log::InfoLog("HTML-Object tag found in message %s from %s",
+      MailScanner::Log::NoticeLog("HTML-Object tag found in message %s from %s",
         $id, $message->{from}) if $loggingtags;
       if ($allowobjects) {
         if ($stripdangerous) {
