@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ZMDiskStore.pm,v 1.1.2.12 2005/03/23 12:03:01 jkf Exp $
+#   $Id: ZMDiskStore.pm 3593 2006-05-29 16:55:28Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ use MailScanner::Config;
 use vars qw($VERSION @DeletesPending);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.12 $, 10;
+$VERSION = substr q$Revision: 3593 $, 10;
 
 # List of pending delete operations so we can clear up properly when killed
 @DeletesPending = ();
@@ -64,7 +64,7 @@ $VERSION = substr q$Revision: 1.1.2.12 $, 10;
 #use vars qw($VERSION);
 #
 #### The package version, both in 1.23 style *and* usable by MakeMaker:
-#$VERSION = substr q$Revision: 1.1.2.12 $, 10;
+#$VERSION = substr q$Revision: 3593 $, 10;
 
 # Attributes are
 #
@@ -221,11 +221,12 @@ sub WriteHeader {
                                 "message %s, %s", $message->{id}, $!);
 
   if( $this->{body}[0] eq "ORIGINAL" ) {
-    my $b= Body->new( $this->{hdpath} );
+    #my $b= Body->new( $this->{hdpath} );
+    my $b= Body->new( $this->{inhdhandle} );
     $b->Start();
     my $line;
     #print STDERR "originalBody\n";
-    while( $line= $b->Next() ) {
+    while( defined ($line= $b->Next()) ) {
       $Tf->print($line);
     #print STDERR "BODY:  $line";
     }
@@ -300,7 +301,8 @@ sub ReadBody {
   my $this = shift;
   my($body, $max) = @_;
 
-  my $b= Body->new( $this->{hdpath} );
+  #my $b= Body->new( $this->{hdpath} );
+  my $b= Body->new( $this->{inhdhandle} );
   $b->Start();
   my $line;
   if ($max) {
@@ -423,38 +425,80 @@ sub CopyToDir {
   return "$dir/$hdfile";
 }
 
+# Writes the whole message to a handle.
+# Need to be passed the message to find the headers path
+# as it's not part of the DiskStore.
+# PERT-LEOH: We could optimize saving file position in ReadQf, 
+# and accessing the queue file, directly
+sub ReadMessageHandle {
+  my $this = shift;
+  my ($message, $handle) = @_;
+
+  # Where did we start?
+  my $oldpos = $this->{inhdhandle}->getpos();
+
+  # Write the whole message in RFC822 format to the handle.
+  # That means 1 CR-terminated line for every N record in the file.
+  my $b= Body->new( $this->{inhdhandle} );
+  $b->Start(1);
+  my $line;
+  #print STDERR "originalBody\n";
+  while(defined($line = $b->Next())) {
+    print $handle $line or MailScanner::Log::DieLog("Cannot print " . $this->{hdpath} . " into handle $!, $^E" );
+    #print STDERR "BODY:  $line";
+  }
+  $b->Done();
+
+  # rewind tmpfile to read it later
+  $handle->seek(0,0) or MailScanner::Log::DieLog("Cannot rewind handle $!, $^E" );
+
+  # rewind source files
+  $this->{inhdhandle}->setpos($oldpos);
+
+  #print STDERR "Done ReadMessageHandle\n";
+  return 1;
+}
+
+
 package Body;
 
 use FileHandle;
 
 sub new {
   my $type = shift;
-  my ( $hdpathname )=@_;
+  #my ( $hdpathname )=@_;
+  my ( $handle )=@_;
   my $self=();
-  my $handle= new FileHandle "<$hdpathname";
+  #my $handle= new FileHandle "<$hdpathname";
   if( defined $handle ) {
-    $self={ _hdpathname => $hdpathname, 
+    #$self={ _hdpathname => $hdpathname, 
+    $self={ 
             _handle     => $handle,
             _startpos   => -1 };
 
     bless $self, $type;
   } else {
-    MailScanner::Log::DieLog("Cannot open %s, %s",
-                                $hdpathname, $!);
+    #MailScanner::Log::DieLog("Cannot open %s, %s",
+    #                            $hdpathname, $!);
+    MailScanner::Log::DieLog("Cannot open handle, %s", $!);
   }
   return $self;
 }
 
 sub Start {
-  my ( $this )=@_;
+  #my ( $this )=@_;
+  my ($this,$entiremessage )=@_;
   if( $$this{_startpos} == -1 ) {
+    seek $$this{_handle}, 0, 0; # reset the handle
     my $InHeader = 0;
     #print STDERR "Start\n";
     while($_=$$this{_handle}->getline) {
       #print STDERR "Start LEIDO: $_";
       chomp; # Chomp everything now. We can easily add it back later.
-      s/\015/ /g; # Sanitise everything by removing all embedded <CR>s
-      if ( /^env-end$|^env-eof$/i ) { # The envelope ends here, starting hdr
+      #s/\015/ /g; # Sanitise everything by removing all embedded <CR>s
+      #if ( /^env-end$|^env-eof$/i ) { # The envelope ends here, starting hdr
+      if ( /^env-end\015?$|^env-eof\015?$/i ) { # The envelope ends here, starting hdr
+        last if $entiremessage;
         $InHeader=1;
         #print STDERR "InHeader\n";
         next;
