@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ZMailer.pm,v 1.1.2.39 2005/11/20 14:53:42 jkf Exp $
+#   $Id: ZMailer.pm 3638 2006-06-17 20:28:07Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.39 $, 10;
+$VERSION = substr q$Revision: 3638 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -68,6 +68,8 @@ sub initialise {
   MailScanner::Config::Default('sendmail', '/usr/sbin/sendmail');
   MailScanner::Config::Default('sendmail2',
                                MailScanner::Config::Value('sendmail'));
+  # The default action is to WARN, and return 1
+  MIME::WordDecoder->default->handler('*' => \&MailScanner::Message::WordDecoderKeep7Bit);
   $UnsortedBatchesLeft = 0; # Disable queue-clearing mode
 }
 
@@ -339,7 +341,18 @@ sub ReadQf {
   # much better than the MIME-tools default handling.
   MIME::WordDecoder->default->handler('*' => \&MailScanner::Message::WordDecoderKeep7Bit);
   # Decode the ISO encoded Subject line
-  $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
+  my $TmpSubject = MIME::WordDecoder::unmime($message->{subject});
+  if ($TmpSubject ne $message->{subject}) {
+    # The unmime function dealt with an encoded subject, as it did
+    # something. Allow up to 10 trailing spaces so that SweepContent
+    # is more kind to us and doesn't go and replace the whole subject,
+    # thinking that it is malicious. Total replacement and hence
+    # destruction of unicode subjects is rather harsh when we are just
+    # talking about a few spaces.
+    $TmpSubject =~ s/ {1,10}$//;
+    $message->{subject} = $TmpSubject;
+  }
+  #old $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
 
   # Every zmailer file should at least define the sender, 1 recipient and the
   # IP address. Everything else is optional, and is preserved as
@@ -899,7 +912,7 @@ sub CreateBatch {
   } while $batchempty; # Keep trying until we get something
 
   # Log the number of invalid messages found
-  MailScanner::Log::InfoLog("New Batch: Found invalid queue files: %s",
+  MailScanner::Log::NoticeLog("New Batch: Found invalid queue files: %s",
                             $invalidfiles)
     if $invalidfiles;
   # Log the size of the queue if it is more than 1 batch
@@ -914,7 +927,7 @@ sub CreateBatch {
                             $DirtyMsgs, $DirtyBytes)
     if $DirtyMsgs;
 
-  #MailScanner::Log::InfoLog("New Batch: Archived %d $ArchivedMsgs messages",
+  #MailScanner::Log::NoticeLog("New Batch: Archived %d $ArchivedMsgs messages",
   #                          $ArchivedMsgs)
   #  if $ArchivedMsgs;
 
